@@ -5,19 +5,19 @@ require 'unleash/context'
 require 'unleash/client'
 require 'logger'
 
-Gem.find_files('unleash/strategy/**/*.rb').each { |path| require path }
+Gem.find_files('unleash/strategy/**/*.rb').each{ |path| require path unless path.end_with? '_spec.rb' }
 
 module Unleash
   TIME_RESOLUTION = 3
 
   STRATEGIES = Unleash::Strategy.constants
-    .select { |c| Unleash::Strategy.const_get(c).is_a? Class }
-    .select { |c| !['NotImplemented', 'Base'].include?(c.to_s) }
-    .map { |c|
+    .select{ |c| Unleash::Strategy.const_get(c).is_a? Class }
+    .reject{ |c| ['NotImplemented', 'Base'].include?(c.to_s) }
+    .map do |c|
       lowered_c = c.to_s
       lowered_c[0] = lowered_c[0].downcase
-      [lowered_c.to_sym, Object::const_get("Unleash::Strategy::#{c}").new]
-    }
+      [lowered_c.to_sym, Object.const_get("Unleash::Strategy::#{c}").new]
+    end
     .to_h
 
   class << self
@@ -30,12 +30,11 @@ module Unleash
   end
 
   # Support for configuration via yield:
-  def self.configure()
+  def self.configure
     self.configuration ||= Unleash::Configuration.new
     yield(configuration)
 
     self.configuration.validate!
     self.configuration.refresh_backup_file!
   end
-
 end
